@@ -26,8 +26,7 @@ public:
      * Default constructor, it takes no parent
      * because it will move to KCupsConnection thread
      *
-     * Before calling any method connect to finished() signal or
-     * use waitTillFinished().
+     * Before calling any method connect to finished() signal.
      * You must delete the object manually after finished
      * using deleteLater().
      */
@@ -37,6 +36,7 @@ public:
      * This method creates an event loop
      * and quits after the request is finished
      */
+    [[deprecated("Creates an event loop, do not use with QML components")]]
     void waitTillFinished();
 
     /**
@@ -270,7 +270,7 @@ public:
 
     void authenticateJob(const QString &printerName, const QStringList authInfo, int jobId);
 
-signals:
+Q_SIGNALS:
     void device(const QString &device_class,
                 const QString &device_id,
                 const QString &device_info,
@@ -296,6 +296,7 @@ private:
 
     KCupsConnection *m_connection = nullptr;
     QEventLoop m_loop;
+    QMetaObject::Connection m_loopConnect;
     bool m_finished = true;
     ipp_status_t m_error = IPP_OK;
     http_status_t m_httpStatus;
